@@ -1,4 +1,5 @@
 from tapioca_arbache.tapioca_arbache import (
     PerfilClient, OauthClient, LicencaClient, JogoSelfClient, RelatorioClient,
-    JogoClient, EquipeClient, PlayMidiaClient, InterfaceClient, CrmMidiaClient
+    JogoClient, EquipeClient, PlayMidiaClient, InterfaceClient, CrmMidiaClient,
+    ResultadoJogoClient
 )
